@@ -2,7 +2,7 @@ from concurrent.futures import ThreadPoolExecutor
 from pprint import pformat
 from typing import List, Dict
 
-from pyspark.sql import DataFrame
+from graphlib import TopologicalSorter, CycleError
 
 from sparksampling.engine.base_engine import SparkBaseEngine
 from sparksampling.engine_factory import EngineFactory
@@ -12,7 +12,6 @@ from sparksampling.mixin import acquire_worker, LogMixin, record_job_id
 from sparksampling.proto.sampling_service_pb2 import RelationSamplingRequest
 from sparksampling.sample import SamplingFactory
 from sparksampling.utilities import check_spark_session
-from graphlib import TopologicalSorter, CycleError
 
 
 def _check_param(conf):
@@ -78,6 +77,8 @@ class JobStage(LogMixin):
         self.sampled_path = None
         self.file_format_imp = None
         self.sample_imp = None
+        self.pre_metas = []
+        self.post_metas = []
 
         self._init_sample_imp()
         self._init_file_format()
@@ -108,19 +109,25 @@ class JobStage(LogMixin):
         cond = [getattr(input_df, relation['input_col']) == getattr(relation_df, relation['relation_col'])]
         return input_df.join(relation_df, cond, how='semi')
 
-    def build_dataframe(self):
+    def build_dataframe(self, pre_hook=None, post_hook=None):
         self.log.debug(f'Starting building stage {self.name}')
         if self.input_name:
             self._df = self.name_df_map[self.input_name]
         else:
             self._df = self.file_format_imp.read(self.input_path)
 
+        if pre_hook:
+            self._df, self.pre_metas = pre_hook(self._df)
+
         if self.sample_imp:
             self._df = self.sample_imp.run(self._df)
 
         for relation in self.relations:
             self._df = self._build_relation_dataframe(self._df, relation)
 
+        if post_hook:
+            self._df, self.post_metas = post_hook(self._df)
+
         self.name_df_map[self.name] = self._df
 
     @property
@@ -239,7 +246,7 @@ class RMSEngine(SparkBaseEngine):
         name_df_map = dict()
         for name in build_order:
             stage = JobStage(self.spark, self.name_stage_map[name], name_df_map)
-            stage.build_dataframe()
+            stage.build_dataframe(self.pre_hook, self.post_hook)
             job_seq.append(stage)
         if self.dry_run:
             self.log.info('Dry run, skip export dataframe')
@@ -260,7 +267,11 @@ class RMSEngine(SparkBaseEngine):
         result = []
         for job in seq:
             if job.sampled_path:
-                result.append({'name': job.name, 'sampled_path': job.sampled_path})
+                result.append({
+                    'name': job.name,
+                    'sampled_path': job.sampled_path,
+                    'hook_msg': job.pre_metas + job.post_metas
+                })
         self.log.info(f'result collected: \n{pformat(result)}')
         return result
 
